==> qtjambi-designer-5.15.7-sources.jar: io/qt/designer/QDesignerTaskMenuExtension.java <==
package io.qt.designer;


/**
 * <p>Allows you to add custom menu entries to Qt Designer's task menu</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html">QDesignerTaskMenuExtension</a></p>
 */
public interface QDesignerTaskMenuExtension extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QDesignerTaskMenuExtension}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QDesignerTaskMenuExtension
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QDesignerTaskMenuExtension.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public java.util.List<io.qt.widgets.QAction> taskActions(){
                return taskActions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.util.List<io.qt.widgets.QAction> taskActions_native_constfct(long __this__nativeId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QDesignerTaskMenuExtension instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html#preferredEditAction">QDesignerTaskMenuExtension::preferredEditAction()const</a></p>
         */
        @io.qt.QtUninvokable
        public io.qt.widgets.QAction preferredEditAction(){
            return preferredEditAction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        
        private native static io.qt.widgets.QAction preferredEditAction_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html#taskActions">QDesignerTaskMenuExtension::taskActions()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.util.List<io.qt.widgets.QAction> taskActions();
        
        private native static java.util.List<io.qt.widgets.QAction> taskActions_native_constfct(long __this__nativeId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html#preferredEditAction">QDesignerTaskMenuExtension::preferredEditAction()const</a></p>
     */
    @io.qt.QtUninvokable
    public default io.qt.widgets.QAction preferredEditAction(){
        return Impl.preferredEditAction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html#taskActions">QDesignerTaskMenuExtension::taskActions()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.List<io.qt.widgets.QAction> taskActions();
    
}

==> qtjambi-designer-5.15.10-sources.jar: io/qt/designer/QDesignerTaskMenuExtension.java <==
package io.qt.designer;


/**
 * <p>Allows you to add custom menu entries to Qt Designer's task menu</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html">QDesignerTaskMenuExtension</a></p>
 */
public interface QDesignerTaskMenuExtension extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QDesignerTaskMenuExtension}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QDesignerTaskMenuExtension
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QDesignerTaskMenuExtension.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public java.util.List<io.qt.widgets.QAction> taskActions(){
                return taskActions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.util.List<io.qt.widgets.QAction> taskActions_native_constfct(long __this__nativeId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QDesignerTaskMenuExtension instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html#preferredEditAction">QDesignerTaskMenuExtension::preferredEditAction()const</a></p>
         */
        @io.qt.QtUninvokable
        public io.qt.widgets.QAction preferredEditAction(){
            return preferredEditAction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        
        private native static io.qt.widgets.QAction preferredEditAction_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html#taskActions">QDesignerTaskMenuExtension::taskActions()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.util.List<io.qt.widgets.QAction> taskActions();
        
        private native static java.util.List<io.qt.widgets.QAction> taskActions_native_constfct(long __this__nativeId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html#preferredEditAction">QDesignerTaskMenuExtension::preferredEditAction()const</a></p>
     */
    @io.qt.QtUninvokable
    public default io.qt.widgets.QAction preferredEditAction(){
        return Impl.preferredEditAction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignertaskmenuextension.html#taskActions">QDesignerTaskMenuExtension::taskActions()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.List<io.qt.widgets.QAction> taskActions();
    
}
